_ego.io_ is the the io package of the _open_eGo_ project. OEDB table ORM objects are defined here and small helpers for io tasks are contained.

Be aware, this repository is currently under heavy development and may be restructured once.
